@@ -1,5 +1,5 @@
 <?php
-// $Id: views-more.tpl.php,v 1.2 2008/04/11 08:46:26 merlinofchaos Exp $
+// $Id: views-more.tpl.php,v 1.3 2009/06/02 20:35:52 merlinofchaos Exp $
 /**
  * @file views-more.tpl.php
  * Theme the more link
@@ -12,6 +12,6 @@
 
 <div class="more-link">
   <a href="<?php print $more_url ?>">
-    <?php print t('more'); ?>
+    <?php print $link_text; ?>
   </a>
 </div>
