@@ -1,5 +1,5 @@
 <?php
-// $Id: views-view-summary-unformatted.tpl.php,v 1.2 2009/01/07 19:21:34 merlinofchaos Exp $
+// $Id: views-view-summary-unformatted.tpl.php,v 1.2.4.1 2010/03/16 23:12:31 merlinofchaos Exp $
 /**
  * @file views-view-summary-unformatted.tpl.php
  * Default simple view template to display a group of summary lines
@@ -9,10 +9,10 @@
  * @ingroup views_templates
  */
 ?>
-<?php foreach ($rows as $row): ?>
+<?php foreach ($rows as $id => $row): ?>
   <?php print (!empty($options['inline']) ? '<span' : '<div') . ' class="views-summary views-summary-unformatted">'; ?>
     <?php if (!empty($row->separator)) { print $row->separator; } ?>
-    <a href="<?php print $row->url; ?>"><?php print $row->link; ?></a>
+    <a href="<?php print $row->url; ?>"<?php print !empty($classes[$id]) ? ' class="'. $classes[$id] .'"' : ''; ?>><?php print $row->link; ?></a>
     <?php if (!empty($options['count'])): ?>
       (<?php print $row->count; ?>)
     <?php endif; ?>
