@@ -1,5 +1,5 @@
 <?php
-// $Id: views-view-summary.tpl.php,v 1.6 2009/01/07 19:21:34 merlinofchaos Exp $
+// $Id: views-view-summary.tpl.php,v 1.6.4.1 2010/03/16 23:12:31 merlinofchaos Exp $
 /**
  * @file views-view-summary.tpl.php
  * Default simple view template to display a list of summary lines
@@ -9,8 +9,8 @@
 ?>
 <div class="item-list">
   <ul class="views-summary">
-  <?php foreach ($rows as $row): ?>
-    <li><a href="<?php print $row->url; ?>"><?php print $row->link; ?></a>
+  <?php foreach ($rows as $id => $row): ?>
+    <li><a href="<?php print $row->url; ?>"<?php print !empty($classes[$id]) ? ' class="'. $classes[$id] .'"' : ''; ?>><?php print $row->link; ?></a>
       <?php if (!empty($options['count'])): ?>
         (<?php print $row->count?>)
       <?php endif; ?>
